Learn R Programming

ebGenotyping (version 1.0)

delta.recal: One step maximization of delta when given other parameters

Description

delta.recal calculates the optimal estimator of certain sample effect when given other parameters.

Usage

delta.recal(dat, cvg, zm1, z0, zp1, mu, eta)

Arguments

dat
a vetor of the same length as number of positions: the non-reference counts of the jth sample at m positions.
cvg
a vetor of the same length as number of positions: the coverage of jth sample at m positions.
zm1
a vetor of the same length as number of positions: posterior probability of RR of the jth sample.
z0
a vetor of the same length as number of positions: posterior probability of RV of the jth sample.
zp1
a vetor of the same length as number of positions: posterior probability of VV of the jth sample.
mu
a vetor of the same length as number of positions: the estimator of mu(position effects).
eta
a single value representing the estimator of eta.

Value

  • a single value representing one step maximization of delta of this sample.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.