Learn R Programming

ebGenotyping (version 1.0)

ebGenotyping-package: Genotyping using Next Generation Sequencing Data

Description

Genotyping the population using next generation sequencing data is essentially important for the rare variant detection. In order to distinguish the genomic structural variation from sequencing error, we propose a statistical model which involves the genotype effect through a latent variable to depict the distribution of non-reference allele frequency data among different samples and different genome loci, while decomposing the sequencing error into sample effect and positional effect. An ECM algorithm is implemented to estimate the model parameters, and then the genotypes and SNPs are inferred based on the empirical Bayes method.

Arguments

Details

ll{ Package: ebGenotyping Type: Package Version: 1.0 Date: 2015-04-04 License: GPL-2 } The most important function is ECM, which is used to establish the model described in 'Genotyping for Rare Variant Detection Using Next-generation Sequencing Data' and do genotyping using NGS data.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.