Learn R Programming

ebGenotyping (version 1.0)

f.delta.1: The first-order derivative with respect to delta

Description

f.delta.1 calculates the first-order derivative of Q function with respect to delta.

Usage

f.delta.1(x, mu, eta, dat, cvg, zm1, z0, zp1)

Arguments

x
a vetor of the same length as number of samples: the current estimate of delta.
mu
a vetor of the same length as number of positions: the current estimate of mu.
eta
a single value: the current estimate of eta.
dat
a n*m matrix: the ith row, jth column of the matrix represents the non-reference counts of ith sample at jth position.
cvg
a n*m matrix: the ith row, jth column of the matrix represents the depth of ith sample at jth position.
zm1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
z0
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
zp1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.

Value

  • a vetor of the same length as number of samples: the first-order derivative with respect to delta.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.