Learn R Programming

ebGenotyping (version 1.0)

f.eta: A part of Q function which is related to eta

Description

f.eta is the objective function of eta estimate when given other parameters.

Usage

f.eta(x, mu, delta, zm1, z0, zp1, dat, cvg)

Arguments

x
a single value: the current estimate of eta
mu
a vetor of the same length as number of positions: the current estimate of mu.
delta
a vetor of the same length as number of samples: the current estimate of delta.
zm1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
z0
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
zp1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.
dat
a n*m matrix: the ith row, jth column of the matrix represents the non-reference counts of ith sample at jth position.
cvg
a n*m matrix: the ith row, jth column of the matrix represents the depth of ith sample at jth position.

Value

  • a single value: the value of the objective function.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.