Arguments
x
a single value: the current estimate of eta.
mu
a vetor of the same length as number of positions: the current estimate of mu.
delta
a vetor of the same length as number of samples: the current estimate of delta.
dat
a n*m matrix: the ith row, jth column of the matrix represents the non-reference counts of ith sample at jth position.
cvg
a n*m matrix: the ith row, jth column of the matrix represents the depth of ith sample at jth position.
zm1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
z0
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
zp1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.