Learn R Programming

ebGenotyping (version 1.0)

loglike: The observed data log-likelihood

Description

loglike is the observed data log-likelihood

Usage

loglike(mu, delta, eta, pRR, pRV, dat, cvg)

Arguments

mu
a vetor of the same length as number of positions: the current estimate of mu.
delta
a vetor of the same length as number of samples: the current estimate of delta.
eta
a single value: the current estimate of eta
pRR
the prior probability of RR
pRV
the prior probability of RV
dat
a n*m matrix: the ith row, jth column of the matrix represents the non-reference counts of ith sample at jth position.
cvg
a n*m matrix: the ith row, jth column of the matrix represents the depth of ith sample at jth position.

Value

  • likea single value: the observed data log-likelihood
  • mu.likea vetor of the same length as number of positions: the observed data log-likelihood for each positions
  • delta.likea vetor of the same length as number of samples: the observed data log-likelihood for each samples

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.