Learn R Programming

ebGenotyping (version 1.0)

mu.recal: One step maximization of mu when given other parameters

Description

mu.recal calculates the optimal estimator of the ith position effect when given other parameters.

Usage

mu.recal(dat, cvg, zm1, z0, zp1, delta, eta)

Arguments

dat
a vetor of the same length as number of samples: the non-reference counts of n samples at the ith position.
cvg
a vetor of the same length as number of samples: the coverage of n samples at the ith position.
zm1
a vetor of the same length as number of samples: posterior probability of RR of n samples at the ith position.
z0
a vetor of the same length as number of samples: posterior probability of RV of n samples at the ith position.
zp1
a vetor of the same length as number of samples: posterior probability of VV of n samples at the ith position.
delta
a vetor of the same length as number of samples: the estimator of delta(sample effects).
eta
a single value representing the estimator of eta.

Value

  • a single value representing one step maximization of mu of the ith position.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.