Learn R Programming

ebGenotyping (version 1.0)

z.adj.1: Adjustment based on data

Description

z.adj.1 is a only part of main function of this package. It calculates the posterior probability of RR, RV and VV of n samples at m positions according to the real data.

Usage

z.adj.1(zm1, z0, zp1, pm1, p0, pp1, th1 = 0.5, th2 = NULL, adj = FALSE, adj.idx = NULL)

Arguments

zm1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
z0
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
zp1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.
pm1
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is RR.
p0
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is RV
pp1
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is VV.
th1
a single value: the cutoff of the probability of observing a non-reference count when the genotype is RR.
th2
a single value: the cutoff of the probability of observing a non-reference count when the genotype is VV.
adj
the default is FALSE.
adj.idx
the default is NULL.

Value

  • zm1a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
  • z0a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
  • zp1a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.
  • adjfinal adjustment status which denotes whether the adjustment is done.
  • adj.idxthe sample ID, which needs to be adjusted.

References

Na You and Gongyi Huang.(2015) Genotyping for Rare Variant Detection Using Next-generation Sequencing Data.