Usage
z.adj.1(zm1, z0, zp1, pm1, p0, pp1, th1 = 0.5, th2 = NULL, adj = FALSE, adj.idx = NULL)
Arguments
zm1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RR of the ith sample at jth position.
z0
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of RV of the ith sample at jth position.
zp1
a n*m matrix: the ith row, jth column of the matrix represents the posterior probability of VV of the jth sample at jth position.
pm1
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is RR.
p0
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is RV
pp1
a n*m matrix: an estimate of the probability of observing a non-reference count when the genotype is VV.
th1
a single value: the cutoff of the probability of observing a non-reference count when the genotype is RR.
th2
a single value: the cutoff of the probability of observing a non-reference count when the genotype is VV.
adj.idx
the default is NULL.